# Faros API Python Client

Python client for Faros API which enables Faros app developers to build on top of the Faros API

## Documentation
Please read the Faros documentation to learn more [here][farosdocs]. See the Faros apps [github repo][farosapps] 
for example and community apps to get you started.

[farosdocs]: https://www.faros.ai/docs
[farosapps]: https://github.com/faros-ai/faros-apps
